#!/bin/bash
#
# Guralp Configuration System
#   Copyright (c) 2008-2010 Guralp Systems Ltd. All rights reserved.
#
#   CD1.1 multiplexor config

# Handle the navbar query without loading anything
if [ "X$1" == "X--navbar" ]
then
	echo "servicestop	Services"
	echo "servicessub/data-mux-cd11	data-mux-cd11"
	echo "data-mux-cd11/$3	$3"
	exit 0
fi

# Load support functions
script_dir=$(dirname $0)
. $script_dir/functions.sh
. $script_dir/svc_funcs.sh


do_read() {
	# Standard control info
	gcs_svc_read || return 1

	# Now the service type dependant variables

	gcs_var "d_dbdir"			"/var/lib/${name}.${sel}"
	gcs_var "d_transmit_wait"		"5"
	gcs_var "d_deferred_transmit_wait"	""
	gcs_var "d_debug_trace_file"		""

	if [ -r "$CFGFILE" ]
	then
	    gcs_var_o "dbdir"
	    gcs_var_o "transmit_wait"
	    gcs_var_o "deferred_transmit_wait"
	    gcs_var_o "debug_trace_file"
	fi
}


do_check() {

	gcs_read_vars

	# Standard service control/info vars
	gcs_svc_check
}


do_write() {
	do_check
	if (( gcs_errors > 0 ))
	then
	    return
	fi

	if gcs_truefalse "${new_delete:-false}"
	then
		gcs_svc_delete "$name" "$sel"
	fi

	gcs_ensure_cfgfile_exists $CFGFILE

	# Standard path controls
	gcs_set_varf DESC	$CTLFILE "$desc"

	# Do the simple keywords in place
	gcs_set_varcf   "application_description" "${CFGFILE}"  "${desc}"
	gcs_set_varcf	"sink_socket_path"	"${CFGFILE}"	"/var/run/${name}.${sel}.sink"
	gcs_set_varcf	"sink_socket_mode"	"${CFGFILE}"	"0666"
	gcs_set_varcf	"source_socket_path"	"${CFGFILE}"	"/var/run/${name}.${sel}.source"
	gcs_set_varcf	"source_socket_group"	"${CFGFILE}"	"data"
	gcs_set_varcf	"source_socket_mode"	"${CFGFILE}"	"0660"
	gcs_set_varcf	"dbdir"			"${CFGFILE}"	"${new_dbdir}"
	gcs_set_varcf	"dbdir_group"		"${CFGFILE}"	"data"
	gcs_set_varcf	"dbdir_mode"		"${CFGFILE}"	"02775"
	gcs_set_varcf	"transmit_wait"		"${CFGFILE}"	"${new_transmit_wait}"
	gcs_set_varcf	"deferred_transmit_wait"	"${CFGFILE}"	"${new_deferred_transmit_wait}"

	# Update the service script
	gcs_update_svc "$name" "$sel" "$enable" "$desc" "$CFGFILE" "$CTLFILE" \
			"$SRVBASE"
	
	gcs_svc_reload "$name" "$sel"
}


name="$2"
sel="$3"

CFGFILE="$CONFIGDIR/$name/${sel}.local"
CTLFILE="$CONFIGDIR/$name/${sel}.ctl.local"
SRVBASE="$SERVDIR/$name"


case "X$1" in
X--check)	do_check	;;
X--write)	do_write	;;
X--read)	do_read		;;
*)		exit 1		;;
esac

gcs_cleanup
exit 0
